#
# spec file for package oidentd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%bcond_without systemd
Name:           oidentd
Version:        3.1.0
Release:        3.1
Summary:        Configurable IDENT Server That Supports NAT/IP Masquerading
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://oidentd.janikrabe.com/
Source:         https://files.janikrabe.com/pub/oidentd/releases/%{version}/oidentd-%{version}.tar.xz
Source1:        sysconfig.oidentd
Source2:        rc.oidentd
Source3:        oidentd@.service
Source4:        oidentd.socket
Source5:        https://files.janikrabe.com/pub/oidentd/releases/%{version}/oidentd-%{version}.tar.xz.asc
# https://janikrabe.com/key.asc
Source6:        %{name}.keyring
Patch0:         oidentd-%{version}-configure_zstd.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
%if %{with systemd}
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%else
Requires(post): %fillup_prereq
Requires(post): %insserv_prereq
%endif

%description
Oidentd is an ident (rfc1413 compliant) daemon that runs on Linux,
Darwin, FreeBSD, OpenBSD, NetBSD, and Solaris.	oidentd can handle IP
masqueraded/NAT connections on Linux, Darwin, FreeBSD (ipf only),
OpenBSD, and  NetBSD.  Oidentd has a flexible mechanism for specifying
ident responses.  Users can be granted permission to specify their own
ident responses.  Responses can be specified according to host and port
pairs.

%prep
%setup -q
%if 0%{?suse_version} < 1505
%patch -P 0 -p1
%endif

# Avoid "Unknown key name 'XXX' in section 'Service', ignoring." warnings from systemd on older releases
%if 0%{?sle_version}
%if 0%{?sle_version} < 150300
  sed -r -i '/^(Protect(Hostname|KernelLogs|Clock))=/d' %{_sourcedir}/oidentd@.service
%if 0%{?sle_version} < 150200
  sed -r -i '/^(Protect(Home|Hostname|KernelLogs|Clock)|PrivateMounts)=/d' %{_sourcedir}/oidentd@.service
%endif
%endif
%endif
# / sle_version

%build
CFLAGS="%{optflags} -fgnu89-inline"
autoreconf --install --force
%configure
%make_build all

%install
%make_install
mkdir -p %{buildroot}/%{_sysconfdir}  \
         %{buildroot}%{_fillupdir} \
%if %{with systemd}
         %{buildroot}%{_unitdir}
%else
         %{buildroot}%{_sysconfdir}/init.d
%endif
touch %{buildroot}/%{_sysconfdir}/oidentd.conf
touch %{buildroot}/%{_sysconfdir}/oidentd_masq.conf
cp -p %{SOURCE1} %{buildroot}%{_fillupdir}
%if %{with systemd}
install -p -m 0644 %{SOURCE3} %{buildroot}/%{_unitdir}/oidentd@.service
install -p -m 0644 %{SOURCE4} %{buildroot}/%{_unitdir}/oidentd.socket
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
install -p -m 0755 %{SOURCE2} %{buildroot}%{_sysconfdir}/init.d/oidentd
ln -fs %{_sysconfdir}/init.d/oidentd %{buildroot}%{_sbindir}/rcoidentd
%endif

%if %{with systemd}
%pre
%service_add_pre oidentd@.service oidentd.socket
%endif

%post
%if %{with systemd}
%service_add_post oidentd@.service oidentd.socket
%fillup_only
%else
%fillup_and_insserv
%endif

%if %{with systemd}
%preun
%service_del_preun oidentd@.service oidentd.socket
%endif

%postun
%if %{with systemd}
%service_del_postun oidentd@.service oidentd.socket
%else
%restart_on_update
%insserv_cleanup
%endif

%files
%config(noreplace) %ghost %{_sysconfdir}/oidentd.conf
%config(noreplace) %ghost %{_sysconfdir}/oidentd_masq.conf
%if %{with systemd}
%{_unitdir}/oidentd@.service
%{_unitdir}/oidentd.socket
%else
%config %{_sysconfdir}/init.d/oidentd
%endif
%{_fillupdir}/sysconfig.oidentd
%{_sbindir}/oidentd
%{_sbindir}/rcoidentd
%{_mandir}/man5/oidentd.conf.5%{?ext_man}
%{_mandir}/man5/oidentd_masq.conf.5%{?ext_man}
%{_mandir}/man8/oidentd.8%{?ext_man}
%license COPYING*
%doc AUTHORS ChangeLog* NEWS README

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Apr  6 2023 Samu Voutilainen <smar@smar.fi>
- Replaced patch oidentd-3.0.0-configure_zstd.patch with
  oidentd-3.1.0-configure_zstd.patch to fix compilation on 15.4
* Thu Mar 16 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.1.0
  * Allow using masquerading without IPv6 support on Linux.
  * Remove `-S` (`--nosyslog`) from systemd unit files.
  * Warn about missing logs if forking with NOSYSLOG set.
* Fri Oct 21 2022 Andrea Manzini <andrea.manzini@suse.com>
- Add patch oidentd-3.0.0-configure_zstd.patch to fix compilation under <= SP15.4
* Fri Oct 21 2022 Andrea Manzini <andrea.manzini@suse.com>
- Add patch to fix compilation under <= SP15.4
* Sun Oct 16 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.0.0
  * Fail on non-zero EUID if NEED_ROOT is set.
  * Drop support for very old FreeBSD versions.
  * Drop NAT support for DragonFly BSD.
  * Drop NAT support for FreeBSD.
  * Create separate kernel module for DragonFly BSD.
  * Remove '--forward-last' flag (renamed to '--masquerade-first').
  * Remove libudb support (deprecated).
  * Remove '\e' escape sequence for strings in configuration files (deprecated).
  * Remove support for legacy kernels (deprecated).
  * Remove Linux MASQFILE support (deprecated).
  * Remove Linux IPCONNTRACK support (deprecated).
  * Update default configuration file to hide root connections.
  * Compile with ENABLE_DEBUGGING by default.
* Thu Oct 14 2021 Samu Voutilainen <smar@smar.fi>
- Remove unsupported hardening flags when using old version
  with old systemd.
- Removed harden_oidentd@.service.patch as this package is using own
  service instead of upstream one, which also has same security switches.
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_oidentd@.service.patch
  Modified:
  * oidentd@.service
* Tue Jan 26 2021 Wang Jun <jgwang@suse.com>
- Update to version 2.5.0
  * Add '--reply-all' option.
  * Clarify behavior of user configuration files.
  * Import documentation from website.
  * Revert deprecation of '--disable-masq' configure flag.
  * Remove default CFLAGS -fstack-protector -fPIE.
  * Updated signing key file "oidentd.keyring"
* Sat Nov 23 2019 Samu Voutilainen <smar@smar.fi>
- Updated signing key to a new version used to sign the package
* Sat Nov 23 2019 Samu Voutilainen <smar@smar.fi>
- Updated systemd files from upstream
* Sat Nov 23 2019 Samu Voutilainen <smar@smar.fi>
- Version bump to 2.4.0
  Changes in version 2.4.0
  * Linux: removed optional dependency on libcap-ng.
  * Deprecated '\e' escape sequence in configuration files.
  * Fixed incorrect username in log message when spoofing fails.
  * Implemented XDG Base Directory specification
  * ~/.config/oidentd.conf takes precedence over ~/.oidentd.conf
  * Rewrote all manual pages, now licensed under GFDL v1.3+.
  * Prevent overflow when too many replies are specified in the
    system-wide configuration file.
  * Rewrote INSTALL and README files.
  * Improved PRNG interface.
  * Changed project description.
  * Deprecated support for MASQFILE and IPCONNTRACK on Linux.
  * Users of recent kernels are unaffected by this change.
  * Minor bugfixes, cleanups, and improvements.
  * Deprecated support for Darwin.
  * Deprecated support for FreeBSD 1-3.
  * Deprecated support for FreeBSD 4.
  * Deprecated support for NetBSD 1-4.
  * Deprecated support for OpenBSD 2.0-2.3.
  * Deprecated support for OpenBSD 2.4-2.8.
  * Deprecated support for OpenBSD 2.9.
  * Deprecated support for Solaris 2.4.
  * Deprecated support for Solaris 2.5.
  * Deprecated support for Solaris 2.6-2.7.
  * Deprecated support for Solaris 2.8.
  Changes in version 2.3.2
  * Option `--forward` now implies `--masquerade`.
  * Added a warning when the connection limit is exceeded.
  * Added systemd services and a socket file.
  * Added compile-time configuration to `--version` output.
  * Linux: fixed incorrect buffer lengths when compiled with `--disable-ipv6`.
  * Deprecated libudb (user database library) support.
  * Linux: fixed incorrect byte order in libnetfilter_conntrack queries.
  * Linux: fixed a null dereference with libnetfilter_conntrack on kernels
    without a connection tracking file.
  * Build as a position-independent executable and with stack protection.
  * Fixed an invalid comment style in the default oidentd_masq.conf file.
  Changes in version 2.3.1
  * Fixed build with libnetfilter_conntrack on Linux.
  Changes in version 2.3.0
  * Added a forwarding capability.
  * Added Linux IPv6 masquerading support.
  * Added build information to `--version` output.
  * Always use libnetfilter_conntrack when available.
  * Fixed signed/unsigned bit shifting on Linux.
  * Minor bugfixes.
* Tue May 29 2018 astieger@suse.com
- fix source URLs and some spec cleanup
* Tue May 29 2018 smar@smar.fi
- Version bump to 2.2.3
- Added bison and flex as build dependencies as upstream changed
  the project to generate the files at the build time
- Removed TODO as it is not present an more
- Changed service file to oidentd@.service, so each opened socket
  can be given own instance.
  FWIW, instead of this, oidentd could be run as a traditional
  daemon, by removing oidentd.socket and flag --stdio from the
  service. For some reason, to resolve boo#953608 @ was removed,
  which prevents using oidentd at least on Leap 15.0.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sat Jan  9 2016 p.drouand@gmail.com
- Rename oidentd@.service to oidentd.service and hardcode variables;
  (boo#953608)
- Add back support for sysconfig in the service file
* Sun Nov  8 2015 lmuelle@suse.com
- Really install the service and socket unit configuration files; (boo#953608).
* Mon Jun  8 2015 schwab@suse.de
- Force gnu89 inline semantics
* Fri Jul 18 2014 p.drouand@gmail.com
- Use systemd instead of sysvinit for openSUSE >= 12.1
- Do not copy the INSTALL file in package documentation; user doesn't
  install from sources
- Get rid of depreciated stuff
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 24 2009 lmuelle@suse.de
- Package the init script with 0755 permissions; (bnc#557358).
* Mon Aug 28 2006 lmuelle@suse.de
- Update to version 2.0.8.
  + Removed spaces between commas and colons from responses.
  + Pulled in patches for Linux from Debian.
  + Open masquerading options before dropping permissions on linux.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 30 2004 mc@suse.de
- Add missing PreReq (#46479)
* Wed Mar 17 2004 lmuelle@suse.de
- inital SuSE RPM
